@@ -1,8 +1,8 @@
-""" Merge files from sources into copious targets. """
-
+""" Merge files from sources into copious targets.
+"""
 import os
-from pybuildtool.core.task import Task as BaseTask
 from shutil import copyfileobj
+from pybuildtool import BaseTask
 
 tool_name = __name__
 
@@ -15,7 +15,8 @@ class Task(BaseTask):
 
     def perform(self):
         if len(self.file_out) != 1:
-            self.bld.fatal('%s can only have one output' % tool_name.capitalize())
+            self.bld.fatal('%s can only have one output' %\
+                    tool_name.capitalize())
 
         if os.path.isdir(self.file_out[0]):
             self.bld.fatal('cannot concat to a directory')
