@@ -6,8 +6,7 @@ Requirements:
     * gzip
 
 """
-
-from pybuildtool.core.task import Task as BaseTask
+from pybuildtool import BaseTask
 
 tool_name = __name__
 
@@ -26,7 +25,8 @@ class Task(BaseTask):
         if len(self.file_in) != 1:
             self.bld.fatal('%s only need one input' % tool_name.capitalize())
         if len(self.file_out) != 1:
-            self.bld.fatal('%s can only have one output' % tool_name.capitalize())
+            self.bld.fatal('%s can only have one output' %\
+                    tool_name.capitalize())
 
         executable = self.env['%s_BIN' % tool_name.upper()]
         return self.exec_command(
