@@ -8,8 +8,7 @@ Requirements:
       to install, run `apt-get install fontforge` (for example)
 
 """
-
-from pybuildtool.core.task import Task as BaseTask
+from pybuildtool import BaseTask
 
 tool_name = __name__
 
